@@ -56,6 +56,7 @@ def create_container(
     reservation_id: "str" = None,
     start: "bool" = True,
     start_timeout: "int" = None,
+    platform_version: "int" = None,
     **kwargs,
 ) -> "Container":
     """Create a container instance.
@@ -107,6 +108,8 @@ def create_container(
     hints = kwargs.setdefault("hints", {})
     if reservation_id:
         hints["reservation"] = reservation_id
+    if platform_version:
+        hints["platform_version"] = platform_version
 
     # Support simpler syntax for exposed_ports
     if exposed_ports and isinstance(exposed_ports, list):
@@ -126,16 +129,20 @@ def create_container(
         runtime=runtime,
         **kwargs,
     )
-
-    if start:
-        timeout = start_timeout or (60 * 30)
-        LOG.info(f"Waiting up to {timeout}s for container creation ...")
-        # Wait for a while, the image may need to download. 30 minutes is
-        # _quite_ a long time, but the user can interrupt or choose a smaller
-        # timeout.
+    
+    # Wait for a while, the image may need to download. 30 minutes is
+    # _quite_ a long time, but the user can interrupt or choose a smaller
+    # timeout.
+    timeout = start_timeout or (60 * 30)
+    LOG.info(f"Waiting up to {timeout}s for container creation ...")
+    
+    if platform_version == 2:
+        container = _wait_for_status(container.uuid, "Running", timeout=timeout)
+    else:
         container = _wait_for_status(container.uuid, "Created", timeout=timeout)
-        LOG.info("Starting container ...")
-        zun().containers.start(container.uuid)
+        if start:
+            LOG.info("Starting container ...")
+            zun().containers.start(container.uuid)
 
     return container
 
